@@ -1,5 +1,5 @@
 /*  hex2nsp - an D-USB packet decompiler
- *  Copyright (C) 2005-2007  Romain Liévin
+ *  Copyright (C) 2005-2007  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,9 +23,8 @@
 #include <string.h>
 #include <sys/stat.h>
 
-#include "ticables.h"
 #include "logging.h"
-#include "internal.h"
+#include "stdints1.h"
 
 #define HEXDUMP_SIZE	12
 
@@ -75,13 +74,11 @@ static const ServiceId sids[] =
 {
 	{ 0x00FE, "Reception Acknowledgment" },
 	{ 0x00FF, "Reception Ack" },
-	{ 0x4001, "Null" },
 	{ 0x4002, "Echo" },
 	{ 0x4003, "Device Address Request" },
 	{ 0x4020, "Device Information" },
 	{ 0x4021, "Screen Capture" },
 	{ 0x4024, "Screen Capture w/ RLE" },
-	{ 0x4042, "Keypresses" },
 	{ 0x4050, "Login" },
 	{ 0x4060, "File Management" },
 	{ 0x4080, "OS Installation" },
@@ -112,30 +109,20 @@ static const ServiceId sids[] =
 static const char* name_of_sid(uint16_t id)
 {
 	int i;
-
-	for (i=0; sids[i].name; i++)
-	{
-		if (id == sids[i].value)
-		{
+  
+	for(i=0; sids[i].name; i++)
+		if(id == sids[i].value)
 			return sids[i].name;
-		}
-	}
-
 	return "???";
 }
 
 static const char* name_of_addr(uint16_t addr)
 {
 	int i;
-
-	for (i=0; addrs[i].name; i++)
-	{
-		if (addr == addrs[i].value)
-		{
+  
+	for(i=0; addrs[i].name; i++)
+		if(addr == addrs[i].value)
 			return addrs[i].name;
-		}
-	}
-
 	return "??";
 }
 
@@ -151,13 +138,9 @@ static const char* name_of_addr(uint16_t addr)
 static int add_sid(uint16_t* array, uint16_t id, int *count)
 {
 	int i;
-	for (i = 0; i < *count; i++)
-	{
-		if (array[i] == id)
-		{
+	for(i = 0; i < *count; i++)
+		if(array[i] == id)
 			return 0;
-		}
-	}
 
 	if (i < ARRAY_SIZE - 1)
 	{
@@ -180,14 +163,10 @@ static int add_sid(uint16_t* array, uint16_t id, int *count)
 static int add_addr(uint16_t* array, uint16_t addr, int *count)
 {
 	int i;
-
-	for (i = 0; i < *count; i++)
-	{
-		if (array[i] == addr)
-		{
+	
+	for(i = 0; i < *count; i++)
+		if(array[i] == addr)
 			return 0;
-		}
-	}
 
 	if (i < ARRAY_SIZE - 1)
 	{
@@ -218,35 +197,23 @@ static int hex_read(unsigned char *data)
 	int ret;
 	int data2;
 
-	if (feof(hex))
-	{
+	if(feof(hex))
 		return -1;
-	}
 
 	ret = fscanf(hex, "%02X", &data2);
-	if (ret < 1)
-	{
+	if(ret < 1)
 		return -1;
-	}
 	*data = data2 & 0xFF;
-	if (fgetc(hex) < 0)
-	{
-		return -1;
-	}
+	fgetc(hex);
 	idx++;
 
-	if (idx >= 16)
+	if(idx >= 16)
 	{
 		int i;
 
 		idx = 0;
-		for (i = 0; (i < 67-49) && !feof(hex); i++)
-		{
-			if (fgetc(hex) < 0)
-			{
-				return -1;
-			}
-		}
+		for(i = 0; (i < 67-49) && !feof(hex); i++)
+			fgetc(hex);
 	}
     
 	return 0;
@@ -258,7 +225,7 @@ static int sif=0, af=0;
 
 static int dusb_write(int dir, uint8_t data)
 {
-	static uint8_t array[20];
+	static int array[20];
   	static int i = 0;
 	static unsigned long state = 1;
 	static uint16_t src_addr, src_id;
@@ -267,10 +234,8 @@ static int dusb_write(int dir, uint8_t data)
 	static int cnt;
 	static uint8_t ascii[HEXDUMP_SIZE+1];
 
-	if (logfile == NULL)
-	{
-		return -1;
-	}
+  	if (logfile == NULL)
+    		return -1;
 
 	array[i++ % 16] = data;
 
@@ -283,7 +248,7 @@ static int dusb_write(int dir, uint8_t data)
 	case 3:			// source address
 		break;
 	case 4: 
-		src_addr = (((uint16_t)(array[2])) << 8) | ((uint16_t)(array[3]));
+		src_addr = (array[2] << 8) | (array[3] << 0);
 		fprintf(logfile, "%04x:", src_addr);
 		add_addr(addr_found, src_addr, &af);
 		break;
@@ -291,7 +256,7 @@ static int dusb_write(int dir, uint8_t data)
 	case 5:			// source service id
 		break;
 	case 6: 
-		src_id = (((uint16_t)(array[4])) << 8) | ((uint16_t)(array[5]));
+		src_id = (array[4] << 8) | (array[5] << 0);
 		fprintf(logfile, "%04x->", src_id);
 		add_sid(sid_found, src_id, &sif);
 		break;
@@ -299,7 +264,7 @@ static int dusb_write(int dir, uint8_t data)
 	case 7:			// destination address
 		break;
 	case 8: 
-		dst_addr = (((uint16_t)(array[6])) << 8) | ((uint16_t)(array[7]));
+		dst_addr = (array[6] << 8) | (array[7] << 0);
 		fprintf(logfile, "%04x:", dst_addr);
 		add_addr(addr_found, dst_addr, &af);
 		break;
@@ -307,14 +272,14 @@ static int dusb_write(int dir, uint8_t data)
 	case 9:			// destination service id
 		break;
 	case 10: 
-		dst_id = (((uint16_t)(array[8])) << 8) | ((uint16_t)(array[9]));
+		dst_id = (array[8] << 8) | (array[9] << 0);
 		fprintf(logfile, "%04x ", dst_id);
 		add_sid(sid_found, src_id, &sif);
 		break;
-
+		
 	case 11: break;	// data checksum
 	case 12: break;
-
+		
 	case 13:		// data size
 		data_size = array[12];
 		break;
@@ -337,43 +302,33 @@ static int dusb_write(int dir, uint8_t data)
 			name_of_addr(src_addr), name_of_sid(src_id), 
 			name_of_addr(dst_addr), name_of_sid(dst_id));
 
-		if (data_size == 0)
-		{
+		if(data_size == 0)
 			state = 0;
-		}
 		break;
 
 	default:
-		if (!cnt)
-		{
+		if(!cnt)
 			fprintf(logfile, "\t\t");
-		}
 
 		fprintf(logfile, "%02X ", data);
 		ascii[cnt % HEXDUMP_SIZE] = data;
 
-		if (!(++cnt % HEXDUMP_SIZE))
+		if(!(++cnt % HEXDUMP_SIZE))
 		{
 			fprintf(logfile, " | ");
-			for (i = 0; i < HEXDUMP_SIZE; i++)
-			{
+			for(i = 0; i < HEXDUMP_SIZE; i++)
 				fprintf(logfile, "%c", isalnum(ascii[i]) ? ascii[i] : '.');
-			}
 
 			fprintf(logfile, "\n\t\t");
 		}
-
-		if (--data_size == 0)
+		
+		if(--data_size == 0)
 		{
-			for (i = 0; i < HEXDUMP_SIZE - (cnt%HEXDUMP_SIZE); i++)
-			{
+			for(i = 0; i < HEXDUMP_SIZE - (cnt%HEXDUMP_SIZE); i++)
 				fprintf(logfile, "   ");
-			}
 			fprintf(logfile, " | ");
-			for (i = 0; i < (cnt%HEXDUMP_SIZE); i++)
-			{
+			for(i = 0; i < (cnt%HEXDUMP_SIZE); i++)
 				fprintf(logfile, "%c", isalnum(ascii[i]) ? ascii[i] : '.');
-			}
 
 			fprintf(logfile, "\n");
 			state = 0;
@@ -396,56 +351,46 @@ int nsp_decomp(const char *filename)
 	char src_name[1024];
 	char dst_name[1024];
 	char line[256];
-	unsigned char data = 0;
+	unsigned char data;
 	int i;
 
-	snprintf(src_name, sizeof(src_name) - 1, "%s.hex", filename);
-	src_name[sizeof(src_name) - 1] = 0;
+	strcpy(src_name, filename);
+	strcat(src_name, ".hex");
 
-	snprintf(dst_name, sizeof(dst_name) - 1, "%s.pkt", filename);
-	dst_name[sizeof(dst_name) - 1] = 0;
+	strcpy(dst_name, filename);
+	strcat(dst_name, ".pkt");
 
 	hex = fopen(src_name, "rt");
-	if (hex == NULL)
+	if(hex == NULL)
 	{
 		fprintf(stderr, "Unable to open this file: %s\n", src_name);
 		return -1;
 	}
 
 	logfile = fopen(dst_name, "wt");
-	if (logfile == NULL)
+	if(logfile == NULL)
 	{
 		fprintf(stderr, "Unable to open this file: %s\n", dst_name);
 		fclose(hex);
 		return -1;
 	}
 
+	if (fgets(line, sizeof(line), hex) == NULL) goto exit;
+	if (fgets(line, sizeof(line), hex) == NULL) goto exit;
+	if (fgets(line, sizeof(line), hex) == NULL) goto exit;
+
 	fprintf(logfile, "TI packet decompiler for NSpire, version 1.0\n");
 
-	// skip comments
-	if (   fgets(line, sizeof(line), hex) == NULL
-	    || fgets(line, sizeof(line), hex) == NULL
-	    || fgets(line, sizeof(line), hex) == NULL)
-	{
-		goto exit;
-	}
-
-	while (hex_read(&data) != -1)
+	while(hex_read(&data) != -1)
 	{
 		dusb_write(0, data);
 	}
 
 	fprintf(logfile, "() Service IDs found: ");
-	for(i = 0; i < sif; i++)
-	{
-		fprintf(logfile, "%04x ", sid_found[i]);
-	}
+	for(i = 0; i < sif; i++) fprintf(logfile, "%04x ", sid_found[i]);
 	fprintf(logfile, "\n");
 	fprintf(logfile, "() Addresses found: ");
-	for(i = 0; i < af; i++)
-	{
-		fprintf(logfile, "%04x ", addr_found[i]);
-	}
+	for(i = 0; i < af; i++) fprintf(logfile, "%04x ", addr_found[i]);
 	fprintf(logfile, "\n");
 
 exit:
@@ -458,6 +403,8 @@ exit:
 #if 0
 int main(int argc, char **argv)
 {
+
+
 	if(argc < 2)
 	{
 		fprintf(stderr, "Usage: hex2nsp [file]\n");
