@@ -31,87 +31,68 @@
 
 #include "ticables.h"
 #include "gettext.h"
-#include "internal.h"
 
-int noop_prepare(CableHandle *h)
+int nul_prepare(CableHandle *h)
 {
-	(void)h;
 	return 0;
 }
 
-int noop_probe(CableHandle *h)
+int nul_probe(CableHandle *h)
 {
-	(void)h;
 	return 0;
 }
 
-int noop_open(CableHandle *h)
+int nul_open(CableHandle *h)
 {
-	(void)h;
 	return 0;
 }
 
-int noop_close(CableHandle *h)
+int nul_close(CableHandle *h)
 {
-	(void)h;
 	return 0;
 }
 
-int noop_reset(CableHandle *h)
+int nul_reset(CableHandle *h)
 {
-	(void)h;
 	return 0;
 }
 
-int noop_put(CableHandle *h, uint8_t *data, uint32_t len)
+int nul_put(CableHandle *h, uint8_t *data, uint32_t len)
 {
-	(void)h, (void)data, (void)len;
 	return 0;
 }
 
-int noop_get(CableHandle *h, uint8_t *data, uint32_t len)
+int nul_get(CableHandle *h, uint8_t *data, uint32_t len)
 {
-	(void)h, (void)data, (void)len;
 	return 0;
 }
 
-int noop_check(CableHandle *h, int *status)
+int nul_check(CableHandle *h, int *status)
 {
-	(void)h;
 	*status = STATUS_NONE;
 	return 0;
 }
 
-int noop_set_red_wire(CableHandle *h, int b)
+int nul_set_red_wire(CableHandle *h, int b)
 {
-	(void)h, (void)b;
 	return 0;
 }
 
-int noop_set_white_wire(CableHandle *h, int b)
+int nul_set_white_wire(CableHandle *h, int b)
 {
-	(void)h, (void)b;
 	return 0;
 }
 
-int noop_get_red_wire(CableHandle *h)
+int nul_get_red_wire(CableHandle *h)
 {
-	(void)h;
 	return 1;
 }
 
-int noop_get_white_wire(CableHandle *h)
+int nul_get_white_wire(CableHandle *h)
 {
-	(void)h;
 	return 1;
 }
 
-int noop_set_device(CableHandle *h, const char * device)
-{
-	(void)h, (void)device;
-	return 0;
-}
-
 const CableFncts cable_nul = 
 {
 	CABLE_NUL,
@@ -119,13 +100,11 @@ const CableFncts cable_nul =
 	N_("Dummy link"),
 	N_("Dummy link used when no cable is set"),
 	0,
-	&noop_prepare,
-	&noop_open, &noop_close, &noop_reset, &noop_probe, NULL,
-	&noop_put, &noop_get, &noop_check,
-	&noop_set_red_wire, &noop_set_white_wire,
-	&noop_get_red_wire, &noop_get_white_wire,
-	NULL, NULL,
-	&noop_set_device
+	&nul_prepare,
+	&nul_open, &nul_close, &nul_reset, &nul_probe, NULL,
+	&nul_put, &nul_get, &nul_check,
+	&nul_set_red_wire, &nul_set_white_wire,
+	&nul_get_red_wire, &nul_get_white_wire,
 };
 
 /* no const ! */ CableFncts cable_ilp =
@@ -135,12 +114,9 @@ const CableFncts cable_nul =
 	N_("Dummy link for TiEmu"),
 	N_("Internal Link Port cable for TiEmu (internal use)"),
 	!0,
-	&noop_prepare,
-	&noop_open, &noop_close, &noop_reset, &noop_probe, NULL,
-	&noop_put, &noop_get, &noop_check,
-	&noop_set_red_wire, &noop_set_white_wire,
-	&noop_get_red_wire, &noop_get_white_wire,
-	NULL, NULL,
-	&noop_set_device,
-	NULL
+	&nul_prepare,
+	&nul_open, &nul_close, &nul_reset, &nul_probe, NULL,
+	&nul_put, &nul_get, &nul_check,
+	&nul_set_red_wire, &nul_set_white_wire,
+	&nul_get_red_wire, &nul_get_white_wire,
 };
