@@ -4,7 +4,7 @@
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (c) 1999-2006 Romain Lievin
  *  Copyright (c) 2001 Julien Blache (original author)
- *  Copyright (c) 2007 Romain Lievin (libusb-win32 support)
+ *  Copyright (c) 2007 Romain Livin (libusb-win32 support)
  *  Copyright (c) 2007, 2011 Kevin Kofler (slv_check support)
  *  Copyright (c) 2011 Jon Sturm (libusb-1.0 support)
  *  Copyright (c) 2011 Lionel Debroux (style fixes, corner case fixes)
@@ -39,11 +39,7 @@
 #include <string.h>
 #include <fcntl.h>
 #include <errno.h>
-#ifdef __BSD__
-#include <libusb.h>
-#else
 #include <libusb-1.0/libusb.h>
-#endif
 
 #ifdef __WIN32__
 #include <winsock2.h> /* struct timeval */
@@ -60,11 +56,8 @@
 #include "../logging.h"
 #include "../error.h"
 #include "../gettext.h"
-#include "../internal.h"
 #if defined(__WIN32__)
 #include "../win32/detect.h"
-#elif defined(__MACOSX__)
-#include "../macos/detect.h"
 #elif defined(__BSD__)
 #include "../bsd/detect.h"
 #else
@@ -104,8 +97,7 @@ static usb_infos tigl_infos[] =
 };
 
 // list of devices found
-static USBCableInfo tigl_devices[MAX_CABLES+1];
-static int tigl_n_devices;
+static usb_infos tigl_devices[MAX_CABLES+1];
 
 // internal structure for holding data
 typedef struct
@@ -113,7 +105,6 @@ typedef struct
 	struct libusb_device *device;
 	struct libusb_device_handle *handle;
 
-	USBCableInfo cable_info;
 	int      nBytesRead;
 	uint8_t  rBuf[64];
 	uint8_t* rBufPtr;
@@ -131,7 +122,6 @@ static int completed = 0;
 // convenient macros
 #define uDev       (((usb_struct *)(h->priv2))->device)
 #define uHdl       (((usb_struct *)(h->priv2))->handle)
-#define cable_info (((usb_struct *)(h->priv2))->cable_info)
 #define max_ps     (((usb_struct *)(h->priv2))->max_ps)
 #define was_max_ps (((usb_struct *)(h->priv2))->was_max_ps)
 #define nBytesRead (((usb_struct *)(h->priv2))->nBytesRead)
@@ -141,7 +131,7 @@ static int completed = 0;
 #define uOutEnd    (((usb_struct *)(h->priv2))->out_endpoint)
 
 #if HAVE_LIBUSB10_STRERROR
-static const char* tigl_strerror(enum libusb_error errcode)
+const char* tigl_strerror(enum libusb_error errcode)
 {
 	return libusb_strerror(errorcode);
 }
@@ -151,7 +141,7 @@ static const char* tigl_strerror(enum libusb_error errcode)
  * libusb-1.0 but as most distros will not be shipping that for a while
  * this will have to do. ~ Jon 2011/02/08
  */
-static const char* tigl_strerror(enum libusb_error errcode)
+const char* tigl_strerror(enum libusb_error errcode)
 {
 	switch (errcode)
 	{
@@ -188,33 +178,42 @@ static const char* tigl_strerror(enum libusb_error errcode)
 }
 #endif
 
-static void tigl_get_product(char * string, size_t maxlen, struct libusb_device *dev)
+static const char* tigl_get_product(struct libusb_device *dev)
 {
 	libusb_device_handle *han;
 	int ret;
+	static unsigned char string[64];
+
 	struct libusb_device_descriptor desc;
 	int r = libusb_get_device_descriptor(dev, &desc);
-
-	string[0] = 0;
-
 	if (r < 0)
 	{
-		ticables_critical("failed to get device descriptor");
+		ticables_error("failed to get device descriptor");
+		return "";
 	}
 
 	if (desc.iProduct)
 	{
 		if (!libusb_open(dev, &han))
 		{
-			ret = libusb_get_string_descriptor_ascii(han, desc.iProduct, (unsigned char *) string, maxlen);
+			ret = libusb_get_string_descriptor_ascii(han, desc.iProduct, string, sizeof(string));
 			libusb_close(han);
-			if (ret <= 0)
+			if (ret > 0)
+			{
+				return (const char *) string;
+			}
+			else
 			{
 				ticables_warning("libusb_get_string_descriptor_ascii (%s).\n", tigl_strerror(ret));
+				return "";
 			}
 		}
-		// else do nothing.
+		else
+		{
+			return "";
+		}
 	}
+	return (const char *)string;
 }
 
 static int tigl_find(void)
@@ -231,9 +230,6 @@ static int tigl_find(void)
 		return 0;
 	}
 
-	memset(tigl_devices, 0, sizeof(tigl_devices));
-	tigl_n_devices = 0;
-
 	for (i = 0; i < cnt; i++)
 	{
 		libusb_device *device = list[i];
@@ -244,28 +240,19 @@ static int tigl_find(void)
 			fprintf(stderr, "failed to get device descriptor");
 			return r;
 		}
-		if (desc.idVendor == VID_TI)
+		if ((desc.idVendor == VID_TI))
 		{
-			for(k = 0; k < (int)(sizeof(tigl_infos) / sizeof(tigl_infos[0])); k++)
+			for(k = 0; k < (int)(sizeof(tigl_infos) / sizeof(usb_infos)); k++)
 			{
-				if (desc.idProduct == tigl_infos[k].pid)
+				if(desc.idProduct == tigl_infos[k].pid)
 				{
-					tigl_devices[j].vid = desc.idVendor;
-					tigl_devices[j].pid = desc.idProduct;
-					tigl_devices[j].version = desc.bcdDevice;
-					tigl_get_product(tigl_devices[j].product_str, sizeof(tigl_devices[j].product_str), device);
 					ticables_info(_(" found %s on #%i, version <%x.%02x>\n"),
-						      tigl_devices[j].product_str, j+1,
+						      tigl_get_product(device), j+1,
 						      desc.bcdDevice >> 8,
 						      desc.bcdDevice & 0xff);
 
+					memcpy(&tigl_devices[j], &tigl_infos[k], sizeof(usb_infos));
 					tigl_devices[j++].dev = device;
-					tigl_n_devices = j;
-
-					if (j >= MAX_CABLES)
-					{
-						return j;
-					}
 				}
 			}
 		}
@@ -294,7 +281,7 @@ static int tigl_open(int id, libusb_device_handle ** udh)
 
 	tigl_enum();
 
-	if (tigl_devices[id].dev == NULL)
+	if(tigl_devices[id].dev == NULL)
 	{
 		return ERR_LIBUSB_OPEN;
 	}
@@ -378,37 +365,31 @@ static int tigl_reset(CableHandle *h)
 
 static int slv_prepare(CableHandle *h)
 {
-	int ret;
 	char str[64];
 
 #if defined(__WIN32__)
-	ret = win32_check_libusb();
-#elif defined(__MACOSX__)
-	ret = macosx_check_libusb();
+	TRYC(win32_check_libusb());
 #elif defined(__BSD__)
-	ret = bsd_check_libusb();
+	TRYC(bsd_check_libusb());
 #else
-	ret = linux_check_libusb();
+	TRYC(linux_check_libusb());
 #endif
-	if (!ret)
-	{
-		if (h->port >= MAX_CABLES)
-		{
-			return ERR_ILLEGAL_ARG;
-		}
 
-		h->address = h->port-1;
-		sprintf(str, "TiglUsb #%i", h->port);
-		h->device = strdup(str);
-		h->priv2 = (usb_struct *)calloc(1, sizeof(usb_struct));
+	if(h->port >= MAX_CABLES)
+	{
+		return ERR_ILLEGAL_ARG;
 	}
 
-	return ret;
+	h->address = h->port-1;
+	sprintf(str, "TiglUsb #%i", h->port);
+	h->device = strdup(str);
+	h->priv2 = (usb_struct *)calloc(1, sizeof(usb_struct));
+
+	return 0;
 }
 
 static int slv_open(CableHandle *h)
 {
-	int ret;
 	int i;
 	struct libusb_config_descriptor *config;
 	const struct libusb_interface *interface_;
@@ -416,13 +397,7 @@ static int slv_open(CableHandle *h)
 	const struct libusb_endpoint_descriptor *endpoint;
 
 	// open device
-	ret = tigl_open(h->address, &uHdl);
-	if (ret)
-	{
-		return ret;
-	}
-
-	cable_info = tigl_devices[h->address];
+	TRYC(tigl_open(h->address, &uHdl));
 	uDev = tigl_devices[h->address].dev;
 	uInEnd  = 0x81;
 	uOutEnd = 0x02;
@@ -480,53 +455,37 @@ static int slv_close(CableHandle *h)
 	return 0;
 }
 
-static int slv_get_device_info(CableHandle *h, CableDeviceInfo *info)
-{
-	translate_usb_device_info(info, &cable_info);
-	return 0;
-}
-
 static int slv_reset(CableHandle *h)
 {
-	int ret;
+	int ret = 0;
 
 	/* Reset both endpoints (send an URB_FUNCTION_RESET_PIPE) */
-	ret = tigl_reset(h);
-	if (!ret)
-	{
-		/* Reset USB port (send an IOCTL_INTERNAL_USB_RESET_PORT) */
-		ret = libusb_reset_device(uHdl);
-		if (ret != 0)
-		{
-			ticables_warning("libusb_device_reset (%s).\n", tigl_strerror(ret));
-			/* On Mac OS X, reenumeration isn't automatic, so let's not return here. */
-#ifndef __MACOSX__
-			ret = ERR_LIBUSB_RESET;
-#else
-			ret = 0;
-#endif
-		}
+	TRYC(tigl_reset(h));
 
-		if (!ret)
-		{
-			// lib-usb doc: after calling usb_reset, the device will need to re-enumerate
-			// and therefore, requires you to find the new device and open a new handle.
-			// The handle used to call usb_reset will no longer work.
+	/* Reset USB port (send an IOCTL_INTERNAL_USB_RESET_PORT) */
+	ret = libusb_reset_device(uHdl);
+	if (ret != 0)
+	{
+		ticables_warning("libusb_device_reset (%s).\n", tigl_strerror(ret));
+		return ERR_LIBUSB_RESET;
+	}
+	else
+	{
+		// lib-usb doc: after calling usb_reset, the device will need to re-enumerate
+		// and thusly, requires you to find the new device and open a new handle. The
+		// handle used to call usb_reset will no longer work.
 #ifdef __WIN32__
-			Sleep(500);
+		Sleep(500);
 #else
-			usleep(500000);
+		usleep(500000);
 #endif
-			ret = slv_close(h);
-			if (!ret)
-			{
-				h->priv2 = (usb_struct *)calloc(1, sizeof(usb_struct));
-				ret = slv_open(h);
-			}
-		}
+		TRYC(slv_close(h));
+
+		h->priv2 = (usb_struct *)calloc(1, sizeof(usb_struct));
+		TRYC(slv_open(h));
 	}
 
-	return ret;
+	return 0;
 }
 
 // convenient function which send one or more bytes
@@ -564,6 +523,7 @@ static int send_block(CableHandle *h, uint8_t *data, int length)
 		}
 	}
 
+
 	return 0;
 }
 
@@ -764,18 +724,13 @@ static int slv_get(CableHandle* h, uint8_t *data, uint32_t len)
 
 static int slv_probe(CableHandle *h)
 {
-	int ret;
 	int i;
 
-	ret = tigl_enum();
-	if (ret)
-	{
-		return ret;
-	}
+	TRYC(tigl_enum());
 
-	for (i = 0; i < MAX_CABLES; i++)
+	for(i = 0; i < MAX_CABLES; i++)
 	{
-		if (tigl_devices[h->address].pid == PID_TIGLUSB)
+		if(tigl_devices[h->address].pid == PID_TIGLUSB)
 		{
 			return 0;
 		}
@@ -786,14 +741,9 @@ static int slv_probe(CableHandle *h)
 
 static int raw_probe(CableHandle *h)
 {
-	int ret;
 	int i;
 
-	ret = tigl_enum();
-	if (ret)
-	{
-		return ret;
-	}
+	TRYC(tigl_enum());
 
 	for(i = 0; i < MAX_CABLES; i++)
 	{
@@ -818,7 +768,7 @@ static int slv_check(CableHandle *h, int *status)
 	int r;
 	struct timeval tv;
 
-	if (nBytesRead > 0)
+	if(nBytesRead > 0)
 	{
 		*status = TRUE;
 		return 0;
@@ -892,6 +842,26 @@ static int slv_check(CableHandle *h, int *status)
 	return 0;
 }
 
+static int slv_set_red_wire(CableHandle *h, int b)
+{
+	return 0;
+}
+
+static int slv_set_white_wire(CableHandle *h, int b)
+{
+	return 0;
+}
+
+static int slv_get_red_wire(CableHandle *h)
+{
+	return 1;
+}
+
+static int slv_get_white_wire(CableHandle *h)
+{
+	return 1;
+}
+
 const CableFncts cable_slv =
 {
 	CABLE_SLV,
@@ -902,11 +872,8 @@ const CableFncts cable_slv =
 	&slv_prepare,
 	&slv_open, &slv_close, &slv_reset, &slv_probe, NULL,
 	&slv_put, &slv_get, &slv_check,
-	&noop_set_red_wire, &noop_set_white_wire,
-	&noop_get_red_wire, &noop_get_white_wire,
-	NULL, NULL,
-	&noop_set_device,
-	&slv_get_device_info
+	&slv_set_red_wire, &slv_set_white_wire,
+	&slv_get_red_wire, &slv_get_white_wire,
 };
 
 const CableFncts cable_raw =
@@ -919,28 +886,31 @@ const CableFncts cable_raw =
 	&slv_prepare,
 	&slv_open, &slv_close, &slv_reset, &raw_probe, NULL,
 	&slv_put, &slv_get, &slv_check,
-	&noop_set_red_wire, &noop_set_white_wire,
-	&noop_get_red_wire, &noop_get_white_wire,
-	NULL, NULL,
-	&noop_set_device,
-	&slv_get_device_info
+	&slv_set_red_wire, &slv_set_white_wire,
+	&slv_get_red_wire, &slv_get_white_wire,
 };
 
 //=======================
 
-// returns list of detected devices
-int usb_probe_device_info(const USBCableInfo **list, int *count)
+TIEXPORT1 int TICALL usb_probe_devices1(int **list);
+
+TIEXPORT1 int TICALL usb_probe_devices(int **list)
 {
-	int ret;
-	if (!(ret = tigl_enum()))
+	return usb_probe_devices1(list);
+}
+
+// returns number of devices and list of PIDs (dynamically allocated)
+TIEXPORT1 int TICALL usb_probe_devices1(int **list)
+{
+	int i;
+
+	TRYC(tigl_enum());
+
+	*list = (int *)calloc(MAX_CABLES+1, sizeof(int));
+	for(i = 0; i < MAX_CABLES; i++)
 	{
-		*list = tigl_devices;
-		*count = tigl_n_devices;
+		(*list)[i] = tigl_devices[i].pid;
 	}
-	else
-	{
-		*list = NULL;
-		*count = 0;
-	}
-	return ret;
+
+	return 0;
 }
