@@ -24,7 +24,7 @@
 
 int log_dbus_start(void);
 int log_dbus_1(int dir, uint8_t data);
-int log_dbus_N(int dir, const uint8_t *data, uint32_t len);
+int log_dbus_N(int dir, uint8_t *data, int len);
 int log_dbus_stop(void);
 
 #endif
