@@ -27,7 +27,6 @@
 #include "../logging.h"
 #include "../error.h"
 #include "../gettext.h"
-#include "../internal.h"
 #include "detect.h"
 #include "ioports.h"
 
@@ -39,21 +38,15 @@
 
 static int ser_prepare(CableHandle *h)
 {
-	const char * device;
 	switch(h->port)
 	{
-	case PORT_1: h->address = 0x3f8; device = "COM1"; break;
-	case PORT_2: h->address = 0x2f8; device = "COM2"; break;
-	case PORT_3: h->address = 0x3e8; device = "COM3"; break;
-	case PORT_4: h->address = 0x3e8; device = "COM4"; break;
+	case PORT_1: h->address = 0x3f8; h->device = strdup("COM1"); break;
+	case PORT_2: h->address = 0x2f8; h->device = strdup("COM2"); break;
+	case PORT_3: h->address = 0x3e8; h->device = strdup("COM3"); break;
+	case PORT_4: h->address = 0x3e8; h->device = strdup("COM4"); break;
 	default: return ERR_ILLEGAL_ARG;
 	}
 
-	if (h->device == NULL)
-	{
-		h->device = strdup(device);
-	}
-
 	// detect OS 
 	if(win32_check_os() == WIN_NT)
 	{
@@ -75,48 +68,34 @@ static int ser_prepare(CableHandle *h)
 	return 0;
 }
 
+static int ser_reset(CableHandle *h);
 static int ser_open(CableHandle *h)
 {
 	// Under Win2k: if we do not open the serial device as a COM
 	// port, it may be impossible to transfer data.
 	// This problem exists with Win2k and some UARTs.
 	// It seems I got the same problem as FlashZ when I changed my 
-	// motherboard. Are some ports broken ?
-	int ret;
+	// motherboard. Are some port broken ?
 	HANDLE hcom;
-	ret = win32_comport_open(h->device, &hcom);
-	if (!ret)
-	{
-		h->priv = (void *)hcom;
-		ret = io_open(com_out);
-		if (!ret)
-		{
-			ret = io_open(com_in);
-		}
-	}
+	TRYC(win32_comport_open(h->device, &hcom));
+	h->priv = (void *)hcom;
+	TRYC(io_open(com_out));
+	TRYC(io_open(com_in));
 
-	return ret;
+	return 0;
 }
 
 static int ser_close(CableHandle *h)
 {
-	int ret;
-	ret = io_close(com_out);
-	if (!ret)
+	TRYC(io_close(com_out));
+	TRYC(io_close(com_in));
 	{
-		ret = io_close(com_in);
-		if (!ret)
-		{
-			HANDLE hcom = hCom;
-			ret = win32_comport_close(&hcom);
-			if (!ret)
-			{
-				h->priv = (void *)hcom;
-			}
-		}
+		HANDLE hcom = hCom;
+		TRYC(win32_comport_close(&hcom));
+		h->priv = (void *)hcom;
 	}
 
-	return ret;
+	return 0;
 }
 
 static int ser_reset(CableHandle *h)
@@ -143,45 +122,37 @@ static int ser_probe(CableHandle *h)
 
 	// 1
 	io_wr(com_out, 2);
-	TO_START(clk);
-	do
+    TO_START(clk);
+    do 
 	{
 		if (TO_ELAPSED(clk, timeout))
-		{
-			return ERR_WRITE_TIMEOUT;
-		}
-	} while ((io_rd(com_in) & 0x10));
-
-	io_wr(com_out, 3);
-	TO_START(clk);
-	do 
+	  		return ERR_WRITE_TIMEOUT;
+    } while ((io_rd(com_in) & 0x10));
+    
+    io_wr(com_out, 3);
+    TO_START(clk);
+    do 
 	{
 		if (TO_ELAPSED(clk, timeout))
-		{
-			return ERR_WRITE_TIMEOUT;
-		}
-	} while ((io_rd(com_in) & 0x10) == 0x00);
+	  		return ERR_WRITE_TIMEOUT;
+    } while ((io_rd(com_in) & 0x10) == 0x00);
 
 	// 0
 	io_wr(com_out, 1);
-	TO_START(clk);
-	do 
+    TO_START(clk);
+    do 
 	{
 		if (TO_ELAPSED(clk, timeout))
-		{
-			return ERR_WRITE_TIMEOUT;
-		}
-	} while (io_rd(com_in) & 0x20);
+	  		return ERR_WRITE_TIMEOUT;
+    } while (io_rd(com_in) & 0x20);
 
-	io_wr(com_out, 3);
-	TO_START(clk);
+    io_wr(com_out, 3);
+    TO_START(clk);
 	do 
 	{
 		if (TO_ELAPSED(clk, timeout))
-		{
-			return ERR_WRITE_TIMEOUT;
-		}
-	} while ((io_rd(com_in) & 0x20) == 0x00);
+	  		return ERR_WRITE_TIMEOUT;
+    } while ((io_rd(com_in) & 0x20) == 0x00);
 
 	return 0;
 }
@@ -189,67 +160,61 @@ static int ser_probe(CableHandle *h)
 static int ser_put(CableHandle *h, uint8_t *data, uint32_t len)
 {
 	int bit;
-	unsigned int i;
+  	unsigned int i;
 	unsigned int j;
-	tiTIME clk;
+  	tiTIME clk;
 
-	for (j = 0; j < len; j++)
+	for(j = 0; j < len; j++)
 	{
 		uint8_t byte = data[j];
 
-		for (bit = 0; bit < 8; bit++)
+  		for (bit = 0; bit < 8; bit++) 
 		{
-			if (byte & 1)
+    		if (byte & 1) 
 			{
-				io_wr(com_out, 2);
-				TO_START(clk);
-				do
+      			io_wr(com_out, 2);
+      			TO_START(clk);
+      			do 
 				{
 					if (TO_ELAPSED(clk, h->timeout))
-					{
-						return ERR_WRITE_TIMEOUT;
-					}
-				} while ((io_rd(com_in) & 0x10));
-
-				io_wr(com_out, 3);
-				TO_START(clk);
-				do
+	  					return ERR_WRITE_TIMEOUT;
+      			} 
+				while ((io_rd(com_in) & 0x10));
+      			
+      			io_wr(com_out, 3);
+      			TO_START(clk);
+      			do 
 				{
 					if (TO_ELAPSED(clk, h->timeout))
-					{
-						return ERR_WRITE_TIMEOUT;
-					}
-				} while ((io_rd(com_in) & 0x10) == 0x00);
-			}
-			else
+	  					return ERR_WRITE_TIMEOUT;
+      			} 
+				while ((io_rd(com_in) & 0x10) == 0x00);
+    		} 
+			else 
 			{
-				io_wr(com_out, 1);
-				TO_START(clk);
-				do
+      			io_wr(com_out, 1);
+      			TO_START(clk);
+      			do 
 				{
 					if (TO_ELAPSED(clk, h->timeout))
-					{
-						return ERR_WRITE_TIMEOUT;
-					}
-				} while (io_rd(com_in) & 0x20);
-
-				io_wr(com_out, 3);
-				TO_START(clk);
+	  					return ERR_WRITE_TIMEOUT;
+      			} 
+				while (io_rd(com_in) & 0x20);
+      		
+      			io_wr(com_out, 3);
+      			TO_START(clk);
 				do 
 				{
 					if (TO_ELAPSED(clk, h->timeout))
-					{
-						return ERR_WRITE_TIMEOUT;
-					}
-				} while ((io_rd(com_in) & 0x20) == 0x00);
-			}
+	  					return ERR_WRITE_TIMEOUT;
+      			} 
+				while ((io_rd(com_in) & 0x20) == 0x00);
+    		}
 
-			byte >>= 1;
-			for (i = 0; i < h->delay; i++)
-			{
-				io_rd(com_in);
-			}
-		}
+    		byte >>= 1;
+    		for (i = 0; i < h->delay; i++)
+      			io_rd(com_in);
+  		}
 	}
 
 	return 0;
@@ -258,63 +223,55 @@ static int ser_put(CableHandle *h, uint8_t *data, uint32_t len)
 static int ser_get(CableHandle *h, uint8_t *data, uint32_t len)
 {
 	int bit;
-	unsigned int i;
+  	unsigned int i;
 	unsigned int j;
-	tiTIME clk;
+  	tiTIME clk;
 
 	for(j = 0; j < len; j++)
 	{
 		uint8_t v, byte = 0;
-
+  	
 		for (bit = 0; bit < 8; bit++) 
 		{
-			TO_START(clk);
-			while ((v = io_rd(com_in) & 0x30) == 0x30)
-			{
-				if (TO_ELAPSED(clk, h->timeout))
+    			TO_START(clk);
+    			while ((v = io_rd(com_in) & 0x30) == 0x30) 
 				{
-					return ERR_READ_TIMEOUT;
-				}
-			}
-
-			if (v == 0x10) 
-			{
-				byte = (byte >> 1) | 0x80;
-				io_wr(com_out, 1);
-
-				TO_START(clk);
-				while ((io_rd(com_in) & 0x20) == 0x00)
-				{
-					if (TO_ELAPSED(clk, h->timeout))
-					{
+      				if (TO_ELAPSED(clk, h->timeout))
 						return ERR_READ_TIMEOUT;
-					}
-				}
-				io_wr(com_out, 3);
-			} 
-			else 
-			{
-				byte = (byte >> 1) & 0x7F;
-				io_wr(com_out, 2);
-
-				TO_START(clk);
-				while ((io_rd(com_in) & 0x10) == 0x00)
+    			}
+    			
+    			if (v == 0x10) 
 				{
-					if (TO_ELAPSED(clk, h->timeout))
-					{
-						return ERR_READ_TIMEOUT;
-					}
-				}
-				io_wr(com_out, 3);
-			}
+	      			byte = (byte >> 1) | 0x80;
+	      			io_wr(com_out, 1);
 
+	      			TO_START(clk);
+	      			while ((io_rd(com_in) & 0x20) == 0x00) 
+					{
+		      			if (TO_ELAPSED(clk, h->timeout))
+			      			return ERR_READ_TIMEOUT;
+	      			}
+	      			io_wr(com_out, 3);
+    			} 
+				else 
+				{
+	      			byte = (byte >> 1) & 0x7F;
+	      			io_wr(com_out, 2);
+
+	      			TO_START(clk);
+	      			while ((io_rd(com_in) & 0x10) == 0x00) 
+					{
+		      			if (TO_ELAPSED(clk, h->timeout))
+	                      		return ERR_READ_TIMEOUT;
+	      			}
+	      			io_wr(com_out, 3);
+    			}
+    		
 			for (i = 0; i < h->delay; i++)
-			{
-				io_rd(com_in);
-			}
-		}
+      				io_rd(com_in);
+  		}
 
-		data[j] = byte;
+  		data[j] = byte;
 	}
 
 	return 0;
@@ -324,10 +281,8 @@ static int ser_check(CableHandle *h, int *status)
 {
 	*status = STATUS_NONE;
 
-	if (!((io_rd(com_in) & 0x30) == 0x30))
-	{
-		*status = STATUS_RX;
-	}
+  	if (!((io_rd(com_in) & 0x30) == 0x30)) 
+    		*status = STATUS_RX;
 
 	return 0;
 }
@@ -338,14 +293,10 @@ static int ser_set_red_wire(CableHandle *h, int b)
 {
 	int v = swap_bits(io_rd(com_in) >> 4);
 
-	if (b)
-	{
-		io_wr(com_out, v | 0x02);
-	}
-	else
-	{
-		io_wr(com_out, v & ~0x02);
-	}
+  	if (b)
+    		io_wr(com_out, v | 0x02);
+  	else
+    		io_wr(com_out, v & ~0x02);
 
 	return 0;
 }
@@ -354,14 +305,10 @@ static int ser_set_white_wire(CableHandle *h, int b)
 {
 	int v = swap_bits(io_rd(com_in) >> 4);
 
-	if (b)
-	{
-		io_wr(com_out, v | 0x01);
-	}
-	else
-	{
-		io_wr(com_out, v & ~0x01);
-	}
+  	if (b)
+    		io_wr(com_out, v | 0x01);
+  	else
+    		io_wr(com_out, v & ~0x01);
 
 	return 0;
 }
@@ -376,37 +323,6 @@ static int ser_get_white_wire(CableHandle *h)
 	return ((0x20 & io_rd(com_in)) ? 1 : 0);
 }
 
-static int ser_set_raw(CableHandle *h, int state)
-{
-	io_wr(com_out, swap_bits(state));
-	return 0;
-}
-
-static int ser_get_raw(CableHandle *h, int *state)
-{
-	*state = (io_rd(com_in) >> 4) & 3;
-	return 0;
-}
-
-static int ser_set_device(CableHandle *h, const char * device)
-{
-	if (device != NULL)
-	{
-		char * device2 = strdup(device);
-		if (device2 != NULL)
-		{
-			free(h->device);
-			h->device = device2;
-		}
-		else
-		{
-			ticables_warning(_("unable to set device %s.\n"), device);
-		}
-		return 0;
-	}
-	return ERR_ILLEGAL_ARG;
-}
-
 const CableFncts cable_ser = 
 {
 	CABLE_BLK,
@@ -419,7 +335,4 @@ const CableFncts cable_ser =
 	&ser_put, &ser_get, &ser_check,
 	&ser_set_red_wire, &ser_set_white_wire,
 	&ser_get_red_wire, &ser_get_white_wire,
-	&ser_set_raw, &ser_get_raw,
-	&ser_set_device,
-	NULL
 };
